@@ -237,7 +237,11 @@ def push_csv2tog(job_id: int, file_path: str, access_token: str):
     data_frame = pd.read_csv(file_path)
     dataset = []
     for _, row in tqdm(data_frame.iterrows(), total=len(data_frame)):
-        alternatives = json.loads(row["alternatives"])
+        if row["alternatives"].isnull():
+            alternatives = []
+        else:
+            alternatives = json.loads(row["alternatives"])
+
         if isinstance(alternatives, list) and isinstance(alternatives[0], dict):
             alternatives = [alternatives]
         dataset.append({
